@@ -30,8 +30,9 @@ import decimal
 import datetime
 import time
 import collections
+import binascii
 
-VERSION = (0, 4, 0)
+VERSION = (0, 4, 1)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -44,10 +45,6 @@ DEBUG = False
 def DEBUG_OUTPUT(s):
     print(s, end=' \n', file=sys.stderr)
 
-def HEX(data):
-    import binascii
-    return binascii.b2a_hex(data)
-
 #-----------------------------------------------------------------------------
 # http://www.postgresql.org/docs/9.3/static/protocol.html
 
@@ -296,17 +293,19 @@ def _decode_column(data, oid, encoding, tzinfo, use_tzinfo):
 # ----------------------------------------------------------------------------
 
 def _bytes_to_bint(b):     # Read as big endian
-    r = 0
-    for n in b:
-        r = r * 256 + (ord(n) if PY2 else n)
-    return r
+    if PY2:
+        r = 0
+        for n in b:
+            r = r * 256 + ord(n)
+        return r
+    else:
+        return int.from_bytes(b, byteorder='big')
 
 def _bint_to_bytes(val):    # Convert int value to big endian 4 bytes.
     if PY2:
         return chr((val >> 24) & 0xff) + chr((val >> 16) & 0xff) + chr((val >> 8) & 0xff) + chr(val & 0xff)
     else:
-        return bytes([(val >> 24) & 0xff, (val >> 16) & 0xff, (val >> 8) & 0xff, val & 0xff])
-
+        return val.to_bytes(4, byteorder='big')
 
 Date = datetime.date
 Time = datetime.time
@@ -517,7 +516,7 @@ class Connection(object):
                     salt = data[4:]
                     hash1 = hashlib.md5(self.password.encode('ascii') + self.user.encode("ascii")).hexdigest().encode("ascii")
                     hash2 = hashlib.md5(hash1+salt).hexdigest().encode("ascii")
-                    self._send_message(PG_F_PASSWORD_MESSAGE, b'md5'+hash2+'\x00')
+                    self._send_message(PG_F_PASSWORD_MESSAGE, b''.join([b'md5',hash2,'\x00']))
                 else:
                     errobj = InterfaceError("Authentication method %d not supported." % (auth_method,))
             elif code == PG_B_PARAMETER_STATUS:
@@ -526,7 +525,7 @@ class Connection(object):
                 if k == b'server_encoding':
                     self.encoding = v.decode('ascii')
             elif code == PG_B_BACKEND_KEY_DATA:
-                if DEBUG: DEBUG_OUTPUT("BACKEND_KEY_DATA:%s" % (HEX(data), ))
+                if DEBUG: DEBUG_OUTPUT("BACKEND_KEY_DATA:%s" % (binascii.b2a_hex(data), ))
             elif code == PG_B_COMMAND_COMPLETE:
                 if obj:
                     command = data[:-1].decode('ascii')
@@ -540,7 +539,7 @@ class Connection(object):
                                 break
             elif code == PG_B_ROW_DESCRIPTION:
                 if obj:
-                    if DEBUG: DEBUG_OUTPUT("ROW_DESCRIPTION:%s" % (HEX(data), ))
+                    if DEBUG: DEBUG_OUTPUT("ROW_DESCRIPTION:%s" % (binascii.b2a_hex(data), ))
                     count = _bytes_to_bint(data[0:2])
                     obj.description = [None] * count
                     n = 2
@@ -555,16 +554,16 @@ class Connection(object):
                         type_code = _bytes_to_bint(data[n+6:n+10])
                         if type_code == PG_TYPE_VARCHAR:
                             size = _bytes_to_bint(data[n+12:n+16]) - 4
-                            precision = None
-                            scale = None
+                            precision = -1
+                            scale = -1
                         elif type_code == PG_TYPE_NUMERIC:
                             size = _bytes_to_bint(data[n+10:n+12])
                             precision = _bytes_to_bint(data[n+12:n+14])
                             scale = precision - _bytes_to_bint(data[n+14:n+16])
                         else:
                             size = _bytes_to_bint(data[n+10:n+12])
-                            precision =None
-                            scale = None
+                            precision = -1
+                            scale = -1
 #                        table_oid = _bytes_to_bint(data[n:n+4])
 #                        table_pos = _bytes_to_bint(data[n+4:n+6])
 #                        size = _bytes_to_bint(data[n+10:n+12])
@@ -577,7 +576,7 @@ class Connection(object):
                     if DEBUG: DEBUG_OUTPUT('\t\t%s' % (obj.description))
             elif code == PG_B_DATA_ROW:
                 if obj:
-                    if DEBUG: DEBUG_OUTPUT("DATA_ROW:%s" % (HEX(data), ))
+                    if DEBUG: DEBUG_OUTPUT("DATA_ROW:%s" % (binascii.b2a_hex(data), ))
                     n = 2
                     row = []
                     while n < len(data):
@@ -594,11 +593,11 @@ class Connection(object):
                     obj._rows.append(tuple(row))
                     if DEBUG: DEBUG_OUTPUT("\t\t%s" % (row, ))
             elif code == PG_B_NOTICE_RESPONSE:
-                if DEBUG: DEBUG_OUTPUT("NOTICE_RESPONSE:%s" % (HEX(data), ))
+                if DEBUG: DEBUG_OUTPUT("NOTICE_RESPONSE:%s" % (binascii.b2a_hex(data), ))
                 for s in data.split(b'\x00'):
                     if DEBUG: DEBUG_OUTPUT("\t\t%s" % (s.decode(self.encoding)))
             elif code == PG_B_ERROR_RESPONSE and not errobj:
-                if DEBUG: DEBUG_OUTPUT("ERROR_RESPONSE:%s" % (HEX(data), ))
+                if DEBUG: DEBUG_OUTPUT("ERROR_RESPONSE:%s" % (binascii.b2a_hex(data), ))
                 err = data.split(b'\x00')
                 for b in err:
                     if DEBUG: DEBUG_OUTPUT("\t\t%s" % (b.decode(self.encoding), ))
@@ -630,7 +629,7 @@ class Connection(object):
                 # send PG_COPY_DONE and PG_F_SYNC
                 self._write(b'c\x00\x00\x00\x04S\x00\x00\x00\x04')
             else:
-                if DEBUG: DEBUG_OUTPUT("SKIP:%d\t%i\t%s" % (code, ln, HEX(data)))
+                if DEBUG: DEBUG_OUTPUT("SKIP:%d\t%i\t%s" % (code, ln, binascii.b2a_hex(data)))
         return errobj
 
     def process_messages(self, obj):
@@ -730,7 +729,7 @@ class Connection(object):
     def cursor(self):
         return Cursor(self)
 
-    def _execute(self, query, obj=None):
+    def _execute(self, query, obj):
         if DEBUG: DEBUG_OUTPUT('Connection::_execute()\t%s' % (query, ))
         self._send_message(
             PG_F_QUERY,
